package com.javacodegeeks.example;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;

import com.atlassian.confluence.content.render.xhtml.ConversionContext;
import com.atlassian.confluence.macro.Macro;
import com.atlassian.confluence.macro.MacroExecutionException;
import com.atlassian.confluence.renderer.radeox.macros.MacroUtils;
import com.atlassian.confluence.spaces.Space;
import com.atlassian.confluence.spaces.SpaceManager;
import com.atlassian.confluence.util.velocity.VelocityUtils;
import com.atlassian.plugin.spring.scanner.annotation.component.Scanned;
import com.atlassian.plugin.spring.scanner.annotation.imports.ComponentImport;
import com.atlassian.upm.api.license.PluginLicenseManager;
import com.atlassian.upm.api.license.entity.PluginLicense;


@Scanned
public class SpacesMacro implements Macro {
	
	private final SpaceManager spaceManager;
	private PluginLicenseManager licenseManager;

	@Autowired
	public SpacesMacro(@ComponentImport SpaceManager spaceManager, 
			@ComponentImport PluginLicenseManager licenseManager) {
		this.spaceManager = spaceManager;
		this.licenseManager = licenseManager;
	}
	
	public SpacesMacro(@ComponentImport SpaceManager spaceManager) {
		this.spaceManager = spaceManager;
	}
	
	@Override
	public String execute(Map<String, String> parameters, String body, ConversionContext context)
			throws MacroExecutionException {
		String errorMessage = null;
		if (licenseManager.getLicense().isDefined())
		{
		   PluginLicense license = licenseManager.getLicense().get();
		   if (license.getError().isDefined()) {
			   switch (license.getError().get()) {
	        	case EXPIRED:
	        		errorMessage = "Your license has expired.";
	        		break;
	        	case TYPE_MISMATCH:
	        		errorMessage = "License type mismatch.";
	        		break;
	        	case USER_MISMATCH:
	        		errorMessage = "License user mismatch.";
	        		break;
	        	case VERSION_MISMATCH:
	        		errorMessage = "License version mismatch.";
	        		break;
				case EDITION_MISMATCH:
					errorMessage = "License edition mismatch.";
					break;
				case ROLE_EXCEEDED:
					errorMessage = "License role exceeded.";
					break;
				case ROLE_UNDEFINED:
					errorMessage = "License role undefined.";
					break;
				default:
					//
	        	}
		   }
		   else {
		        // handle valid license scenario
		   }
		} 
		else {
		     errorMessage = "Unlicensed.";
		}
		
		if (errorMessage != null) {
			Map<String, Object> map = MacroUtils.defaultVelocityContext();
			map.put("errorMessage", errorMessage);
			return VelocityUtils.getRenderedTemplate("templates/license-message.vm", map);
		}
		
		List<Space> spaces = spaceManager.getAllSpaces();
		
		StringBuilder builder = new StringBuilder();
		
		builder.append("<ul>");
		for (Space space : spaces) {
			builder.append("<li>");
			builder.append(space.getName());
			builder.append("</li>");
		}
		builder.append("</ul>");
		
		return builder.toString();
	}

	@Override
	public BodyType getBodyType() {
		return BodyType.NONE;
	}

	@Override
	public OutputType getOutputType() {
		return OutputType.BLOCK;
	}

}
